@@ -118,6 +118,13 @@ do
        new=`echo "$new" |perl -pi -e 's!KIOWidgets/!!g'`;
        new=`echo "$new" |perl -pi -e 's!KActivities/Stats/!!g'`;
        new=`echo "$new" |perl -pi -e 's!KI18n/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KTextEditor/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KPackage/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KPeople/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KActivities/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KFileMetaData/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KCalendarCore/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KDeclarative/!!g'`;
        newname=`echo "$new" |perl -pi -e 's!.h!!'`;
 
        #echo "before go : $new";
@@ -167,6 +174,26 @@ do
                                 fi
                            fi
                         ;;
+         		QDBusArgument)
+                           number=`grep "qdbus_cast"  $file|wc -l`;
+                           if test $number = 0 ; then
+                               remove_include;
+                           fi
+                        ;;
+			QDBusPendingCall)
+                           number=`grep "QDBusConnection::sessionBus().asyncCall"  $file|wc -l`;
+                           if test $number = 0 ; then
+                               remove_include;
+                           fi
+                        ;;
+
+            		QDBusMetaType)
+                           number=`grep "qDBusRegisterMetaType"  $file|wc -l`;
+                           if test $number = 0 ; then
+                               remove_include;
+                           fi
+                        ;;
+
                         QScrollBar)
                            number=`grep "verticalScrollBar()"  $file|wc -l`;
                            if test $number = 0 ; then
@@ -373,6 +400,20 @@ do
                            #     fi
                            #fi
                         ;;
+                        QtDebug)
+                           number=`egrep "qDebug|qWarning|qCritical"  $file|wc -l`;
+                           if test $number = 0 ; then
+                               remove_include;
+                           fi
+                           #number=`grep "qDebug"  $file|wc -l`;
+                           #if test $number = 0 ; then
+                           #     number=`grep "qWarning"  $file|wc -l`;
+                           #     if test $number = 0 ; then
+                           #        remove_include;
+                           #     fi
+                           #fi
+                        ;;
+			
                         QLoggingCategory)
                            number=`egrep "Q_DECLARE_LOGGING_CATEGORY|Q_LOGGING_CATEGORY" $file|wc -l`;
                            if test $number = 0 ; then
@@ -420,6 +461,18 @@ do
                               remove_include;
                            fi
                         ;;
+                        QtTestGui)
+                          number=`egrep "QCOMPARE|QVERIFY|QTEST_GUILESS_MAIN|QTEST" $file|wc -l`;
+                           if test $number = 0 ; then
+                              remove_include;
+                           fi
+                        ;;
+                        QtTestWidgets)
+                          number=`egrep "QCOMPARE|QVERIFY|QTEST_GUILESS_MAIN|QTEST" $file|wc -l`;
+                           if test $number = 0 ; then
+                              remove_include;
+                           fi
+                        ;;
                         QtTest)
                            number=`egrep "QCOMPARE|QVERIFY|QTEST_GUILESS_MAIN|QTEST" $file|wc -l`;
                            if test $number = 0 ; then
